import java.awt.*;
import squint.*;
import javax.swing.*;

/*
 * DisplayHistograms -- Display a set of histograms in a new window
 */
public class DisplayHistograms extends GUIManager {
    // Window dimensions
    private final int MAX_WINDOW_WIDTH = 800, WINDOW_HEIGHT = 300;
    
    // Space desired between histogram images
    private final int PADDING = 2;
    
    // How tall a histogram image will fit in the window
    private final int HIST_HEIGHT = WINDOW_HEIGHT - 40 - 2*PADDING;
    
    // Values that represent colors used to draw histograms
    private final int GRAY = 200;
    private final int BLACK = 0;
    private final int WHITE = 255;
    
    // Create a window containing drawings of the histograms in the parameter array
    public DisplayHistograms( Histogram [] histogram ) {
      contentPane.setLayout( new BorderLayout() );
      
      // A pane to hold the histogram images
      JPanel graphs = new JPanel();
      graphs.setBackground( Color.YELLOW );
      graphs.setLayout( new GridLayout(1, histogram.length, PADDING, 0 ) );
      contentPane.add( graphs, BorderLayout.CENTER );
      
      // A pane to hold the bit/pixel information for each histogram
      JPanel huffmanPane = new JPanel();
      huffmanPane.setLayout( new GridLayout(1, histogram.length, PADDING, 0 ) );     
      contentPane.add( huffmanPane, BorderLayout.SOUTH );
      
      // Construct histogram images and bit/pixel information for each histogram
      int windowWidth = PADDING;
      for ( int c = 0; c < histogram.length; c++ ) {
          graphs.add( new JBarGraph( histogram[c].getData() ) );
          huffmanPane.add( new JLabel( "Bits per pixel = " +  histogram[c].huffmanSize() ) );
      }
      
      // Display the completed window
      this.createWindow( MAX_WINDOW_WIDTH, WINDOW_HEIGHT );
    }
    

}



