import java.awt.*;
import squint.*;
import javax.swing.*;
import java.io.File;

/*
 * ImageViewer --- a GUIManager to display a single image and provide the
 *                 ability to expand the range of that image and to
 *                 see the image's color histograms.
 */
public class ImageViewer extends GUIManager {
    // The image to display
    private SImage picture;
    
    // Label used to display the image
    private JLabel displayImage = new JLabel( "", SwingConstants.CENTER );
   
    private JFileChooser chooser = new JFileChooser( new File( System.getProperty("user.dir")) );

    // Control buttons
    private JButton showHist = new JButton( "Show Histogram" );
    private JButton loadImage = new JButton( "Load Image" );
              
    // Place all the GUI components in the GUIManager's pane
    public ImageViewer() {
      this.createWindow( 400, 400 );
      contentPane.setLayout( new BorderLayout() );
      contentPane.add( new JScrollPane( displayImage ), BorderLayout.CENTER );
      
      JPanel controlPane = new JPanel();
      controlPane.setLayout( new GridLayout( 2, 2 ) );
      controlPane.add( loadImage );
      controlPane.add( showHist );
      
      contentPane.add( controlPane, BorderLayout.SOUTH );
    }
    
    // Display histograms or extend range as requested
    public void buttonClicked( JButton which ) {
        if ( which == loadImage ) {
            if ( chooser.showOpenDialog( this ) == JFileChooser.APPROVE_OPTION ) {
        
                picture = new SImage( chooser.getSelectedFile().getAbsolutePath() );
                setPic( picture );
            }
        } else if ( which == showHist ) {
            Histogram [] histogram = new Histogram[3];
    
            for ( int c = SImage.RED; c <= SImage.BLUE; ++c ) {
                histogram[c] = new Histogram( picture.getPixelArray( c ) );
            }
            new DisplayHistograms( histogram );
            
        } 
    }
    
    // Set the image displayed within the viewer
    public void setPic( SImage newPic ) {
        picture = newPic;
        displayImage.setIcon( picture );
    }
    
    // Get the image displayed within the viewer
    public SImage getPic( ) {
        return picture;
    }
    


}



