import javax.swing.*;
import java.awt.*;

// A Swing component that displays a bar graph of an array of data values
public class JBarGraph extends JComponent {

    // The values to be graphed
    private int [] data;
    
    // The largest value in the data array
    private int maxValue;

    // Create a new bar graph
    public JBarGraph( int [] theData ) {
        // Save the data
        data = theData;
        
        // Determine the maximum value in the data
        maxValue = data[0];
        for ( int b = 1; b < data.length; b++ ) {
            maxValue = Math.max( maxValue, data[b] );
        }
    }
    
    // Draw the desired graph using the Graphics context provided by Swing
    public void paint( Graphics g ) {
        // Determine the bounds of the drawing area
        int width = (int) g.getClipBounds().getWidth();
        int height = (int) g.getClipBounds().getHeight();
        
        // Create a white background
        g.setColor( Color.WHITE );
        g.fillRect( 0, 0, width, height );
        
        // Draw a line for each brightness value in the histogram
        for ( int b = 0; b < data.length; b++ ) {
            if ( b % 10 == 0 ) {  // Add graph paper lines every 10 positions
                g.setColor( Color.GRAY );
                g.drawLine( b, 0, b, height );
                g.setColor( Color.BLACK );
            }
            g.drawLine( b, height - height*data[b]/maxValue, b, height );
        }
        
    }
    
}